%define major		5
%define libname		%mklibname zip %{major}
%define develname	%mklibname zip -d

Summary:	A C library for reading, creating, and modifying zip archives
Name:		libzip
Version:	1.11.2
Release:	%mkrel 1
Group:		System/Libraries
License:	BSD
URL:		https://libzip.org/
Source0:	https://libzip.org/download/%{name}-%{version}.tar.xz

BuildRequires:	cmake
BuildRequires:	groff-for-man
BuildRequires:	libtool
BuildRequires:	pkgconfig(bzip2)
BuildRequires:	pkgconfig(liblzma)
BuildRequires:	pkgconfig(libzstd)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(zlib)

%description
libzip is a C library for reading, creating, and modifying zip archives. Files
can be added from data buffers, files, or compressed data copied directly from
other zip archives. Changes made without closing the archive can be reverted.
The API is documented by man pages.

%package -n	%{libname}
Summary:	A C library for reading, creating, and modifying zip archives
Group:		System/Libraries

%description -n	%{libname}
libzip is a C library for reading, creating, and modifying zip archives. Files
can be added from data buffers, files, or compressed data copied directly from
other zip archives. Changes made without closing the archive can be reverted.
The API is documented by man pages.

%package -n	%{develname}
Summary:	Shared library and header files for the %{name} library
Group:		Development/C
Requires:	%{name} = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	zip-devel = %{version}-%{release}

%description -n	%{develname}
libzip is a C library for reading, creating, and modifying zip archives. Files
can be added from data buffers, files, or compressed data copied directly from
other zip archives. Changes made without closing the archive can be reverted.
The API is documented by man pages.

%prep
%autosetup -p1

# fix test return state
sed -i -e 's:19/2:19/0:' regress/open_nonarchive.test

%build
%cmake -DENABLE_LZMA:BOOL=ON -DENABLE_ZSTD:BOOL=ON
%cmake_build

%install
%cmake_install

%check
pushd build
ctest
popd

%files
%doc AUTHORS NEWS.md README.md THANKS
%{_bindir}/zipcmp
%{_bindir}/zipmerge
%{_bindir}/ziptool
%{_mandir}/man1/zipcmp.1*
%{_mandir}/man1/zipmerge.1*
%{_mandir}/man1/ziptool.1*

%files -n %{libname}
%doc AUTHORS NEWS.md README.md THANKS
%{_libdir}/%{name}.so.%{major}{,.*}

%files -n %{develname}
%doc API-CHANGES.md
%{_includedir}/zip.h
%{_includedir}/zipconf.h
%{_libdir}/cmake/%{name}/
%{_libdir}/%{name}.so
%{_mandir}/man3/*.3.*
%{_libdir}/pkgconfig/%{name}.pc


%changelog
* Fri Nov 01 2024 daviddavid <daviddavid> 1.11.2-1.mga10
+ Revision: 2112024
- new version: 1.11.2

* Fri Oct 13 2023 daviddavid <daviddavid> 1.10.1-1.mga10
+ Revision: 1995893
- new version: 1.10.1

* Sun Oct 09 2022 neoclust <neoclust> 1.9.2-1.mga9
+ Revision: 1896029
- New version 1.9.2

* Thu Mar 24 2022 umeabot <umeabot> 1.8.0-3.mga9
+ Revision: 1824477
- Mageia 9 Mass Rebuild

* Sat Oct 02 2021 wally <wally> 1.8.0-2.mga9
+ Revision: 1747491
- rebuild for openssl 3.0.0

* Thu Aug 05 2021 luigiwalser <luigiwalser> 1.8.0-1.mga9
+ Revision: 1739694
- 1.8.0
- enable zstd compression support

* Wed Oct 21 2020 akien <akien> 1.7.3-3.mga8
+ Revision: 1637663
- Fix bogus provides in library package which prevented r1608975 from working

* Sat Jul 25 2020 daviddavid <daviddavid> 1.7.3-2.mga8
+ Revision: 1608975
- devel pkg require the main pkg
  * CMake Error at /usr/lib(64)/cmake/libzip/libzip-targets.cmake:77 (message):
    * The imported target "zipcmp" references the file "/usr/bin/zipcmp"
      but this file does not exist.

* Thu Jul 16 2020 daviddavid <daviddavid> 1.7.3-1.mga8
+ Revision: 1606598
- new version: 1.7.3

* Sun Jun 14 2020 daviddavid <daviddavid> 1.7.1-1.mga8
+ Revision: 1593282
- new version: 1.7.1
- remove merged upstream patches

* Fri Jun 12 2020 daviddavid <daviddavid> 1.7.0-2.mga8
+ Revision: 1592735
- add upstream patch to re-add missing LIBZIP_VERSION_* macros

* Fri Jun 12 2020 joequant <joequant> 1.7.0-1.mga8
+ Revision: 1592734
- add groff executable for man pages
- update to 1.7.0

* Thu Feb 20 2020 umeabot <umeabot> 1.6.1-2.mga8
+ Revision: 1546512
- Mageia 8 Mass Rebuild

* Mon Feb 03 2020 daviddavid <daviddavid> 1.6.1-1.mga8
+ Revision: 1486645
- new version: 1.6.1

* Fri Jan 24 2020 daviddavid <daviddavid> 1.6.0-1.mga8
+ Revision: 1482700
- new version: 1.6.0
- enable lzma support

* Wed Mar 13 2019 daviddavid <daviddavid> 1.5.2-1.mga7
+ Revision: 1375247
- new version: 1.5.2

* Sun Sep 23 2018 umeabot <umeabot> 1.5.1-2.mga7
+ Revision: 1299295
- Mageia 7 Mass Rebuild

* Mon Aug 06 2018 daviddavid <daviddavid> 1.5.1-1.mga7
+ Revision: 1248291
- new version: 1.5.1

* Thu Dec 28 2017 luigiwalser <luigiwalser> 1.3.2-1.mga7
+ Revision: 1186461
- remove one more multiarch thing from files list
- remove multiarch kludges
- 1.3.2
- library major is now 5
- remove upstream patches
- update URLs
- add patch to fix CVE-2017-14107

* Wed Aug 10 2016 luigiwalser <luigiwalser> 1.1.3-1.mga6
+ Revision: 1045305
- 1.1.3

* Thu Feb 25 2016 oden <oden> 1.1.2-1.mga6
+ Revision: 978908
- 1.1.2
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Sat Nov 14 2015 oden <oden> 1.0.1-1.mga6
+ Revision: 903115
- 1.0.1
- rediff one patch, drop the others
- use the multiarch kludge
- php-7.0.0RC? has bundled libzip-1.0.1 so, should work fine...

* Fri Mar 20 2015 luigiwalser <luigiwalser> 0.11.2-4.mga5
+ Revision: 818999
- rediff patch from php to fix CVE-2015-2331

* Wed Oct 15 2014 umeabot <umeabot> 0.11.2-3.mga5
+ Revision: 742454
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.11.2-2.mga5
+ Revision: 681922
- Mageia 5 Mass Rebuild

* Fri Mar 28 2014 luigiwalser <luigiwalser> 0.11.2-1.mga5
+ Revision: 609119
- 0.11.2
- rediff patch 1
- remove upstreamed portion of patch 2

* Mon Oct 21 2013 umeabot <umeabot> 0.11.1-2.mga4
+ Revision: 540664
- Mageia 4 Mass Rebuild

* Wed Oct 09 2013 dlucio <dlucio> 0.11.1-1.mga4
+ Revision: 494136
- no test for now
+ luigiwalser <luigiwalser>
- 0.11.1
- rediff pkgconfig patch
- update php patch (from fedora)
- remove patches 3 and 4 (fixed upstream)

* Sat Jan 12 2013 cjw <cjw> 0.10.1-3.mga3
+ Revision: 360464
- patch4: fix tests with automake 1.13
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Dec 14 2012 spuhler <spuhler> 0.10.1-2.mga3
+ Revision: 330707
- bumped rel for build mga3
  cleaned spec file for un-needed lines

* Mon Apr 09 2012 pterjan <pterjan> 0.10.1-1.mga2
+ Revision: 229840
- Fix decrypt code on x86_64 with zlib >= 1.2.5.1 (mga#5063)
- Drop obsolete scriptlets
- imported package libzip
+ luigiwalser <luigiwalser>
- 0.10.1 (fix CVE-2012-1162 and CVE-2012-1163)
- add patch 2 (fedora)
+ fwang <fwang>
- add some gentoo patches to fix include headers


* Thu Nov 25 2010 Oden Eriksson <oeriksson@mandriva.com> 0.9.3-3mdv2011.0
+ Revision: 601065
- rebuild

* Mon Apr 26 2010 Emmanuel Andry <eandry@mandriva.org> 0.9.3-2mdv2010.1
+ Revision: 539363
- apply librairies policy
- doesn't need autotools

* Fri Feb 12 2010 Oden Eriksson <oeriksson@mandriva.com> 0.9.3-1mdv2010.1
+ Revision: 504721
- 0.9.3

* Wed Sep 02 2009 Christophe Fergeau <cfergeau@mandriva.com> 0.9-3mdv2010.0
+ Revision: 425977
- rebuild

* Thu Dec 18 2008 Oden Eriksson <oeriksson@mandriva.com> 0.9-2mdv2009.1
+ Revision: 315646
- rebuild

* Sat Jul 26 2008 Oden Eriksson <oeriksson@mandriva.com> 0.9-1mdv2009.0
+ Revision: 250084
- 0.9

* Sat Jun 28 2008 Oden Eriksson <oeriksson@mandriva.com> 0.8-5mdv2009.0
+ Revision: 229719
- rebuild

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Sun Feb 17 2008 Oden Eriksson <oeriksson@mandriva.com> 0.8-3mdv2008.1
+ Revision: 169560
- rebuild

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Tue Sep 18 2007 Guillaume Rousse <guillomovitch@mandriva.org> 0.8-2mdv2008.0
+ Revision: 89855
- rebuild

* Thu Jun 07 2007 Oden Eriksson <oeriksson@mandriva.com> 0.8-1mdv2008.0
+ Revision: 36504
- 0.8


* Sun Mar 04 2007 Oden Eriksson <oeriksson@mandriva.com> 0.8-0.20070304.1mdv2007.0
+ Revision: 132044
- new snap (20070304)
- enable the test suite

* Tue Jan 16 2007 Oden Eriksson <oeriksson@mandriva.com> 0.8-0.20070116.1mdv2007.1
+ Revision: 109377
- use a recent snap (20070116)

* Thu Nov 16 2006 Oden Eriksson <oeriksson@mandriva.com> 0.7.1-5mdv2007.1
+ Revision: 84765
- disable borked tests for now
- bs f*uk
- Import libzip

* Thu Nov 02 2006 Oden Eriksson <oeriksson@mandriva.com> 0.7.1-3
- fix deps

* Sat May 20 2006 Oden Eriksson <oeriksson@mandriva.com> 0.7.1-2mdk
- oops! major bump required

* Fri May 19 2006 Oden Eriksson <oeriksson@mandriva.com> 0.7.1-1mdk
- 0.7.1

* Sun Mar 05 2006 Oden Eriksson <oeriksson@mandriva.com> 0.6.1-1mdk
- initial Mandriva package

